@@ -1,8 +1,8 @@
 #' @rdname getDataCM
 #' @param x an object of class \code{CM_list}
-#' @param tidynames logical, if \code{TRUE} suppress ODK strings
+#' @param tidynames logical, \code{TRUE} make clean column names
 #' @param pivot.wider logical, if \code{TRUE} return a wider object 
-#'  where each observer is a row
+#'  where each tricot package is a row
 #' @param ... additional arguments passed to methods
 #' @importFrom methods as
 #' @method as.data.frame CM_list
@@ -12,75 +12,76 @@ as.data.frame.CM_list <- function(x,
                                   tidynames = TRUE,
                                   pivot.wider = FALSE) {
   
-  dt <- list()
+  dat <- list()
   # 'specialfields', the assessment questions
-  dt[["specialfields"]] <- x[["specialfields"]]
+  dat[["specialfields"]] <- x[["specialfields"]]
   
   # 'project', the project details
-  dt[["project"]] <- x[["project"]]
+  dat[["project"]] <- x[["project"]]
   
   # 'registry', the questions during participant registration
-  dt[["registry"]] <- x[["registry"]]
+  dat[["registry"]] <- x[["registry"]]
   
   # importantfields
-  dt[["importantfields"]] <- x[["importantfields"]]
+  dat[["importantfields"]] <- x[["importantfields"]]
   
   # 'assessments', the survey in trial data assessment
-  dt[["assessments"]] <- x[["assessments"]]
+  dat[["assessments"]] <- x[["assessments"]]
   
   # 'packages', the packages info
-  dt[["packages"]] <- x[["packages"]]
+  dat[["packages"]] <- x[["packages"]]
   
   # 'data', the trial data assessment
-  dt[["data"]] <- x[["data"]]
+  dat[["data"]] <- x[["data"]]
   
   # get the project name
-  project_name <- dt[["project"]]$project_cod
+  project_name <- dat[["project"]]$project_cod
   
   # get variables names from participant registration
-  regs <- dt[["registry"]]
+  regs <- dat[["registry"]]
   
   regs <- regs[["fields"]]
   
   regs_name <- paste0("REG_", regs[, "name"])
   
-  has_data <- length(dt[["data"]]) > 0
+  has_data <- length(dat[["data"]]) > 0
   
-  ncomp <- dt$project$project_numcom
+  ncomp <- dat$project$project_numcom
   
   if (isTRUE(has_data)) {
     
     # get the names of assessments questions
-    assess_q <- dt[["specialfields"]]
-    #assess_q <- assess_q[, "name"]
-    
+    assess_q <- dat[["specialfields"]]
+
     # check if overall VS local is present
     tricotvslocal <- grepl("Performance", assess_q$type)
     
-    # get the ranking questions
+    # get the strings of ranking questions
     rank_q <- assess_q$name[!tricotvslocal]
     
     # and the overall vs local question
     tricotvslocal <- assess_q$name[tricotvslocal]
     
     # get variables names from assessments
-    assess <- dt[["assessments"]]
+    assess <- dat[["assessments"]]
     
-    
-    if(length(assess) > 0) {
+    if (length(assess) > 0) {
       
       assess <- do.call("rbind", assess[, "fields"])
       assess <- data.frame(assess, stringsAsFactors = FALSE)
       assess <- assess[!duplicated(assess[, "name"]), ]
       # the ids for assessments
-      assess_id <- paste0("ASS", dt[["assessments"]][, "code"])
+      assess_id <- paste0("ASS", dat[["assessments"]][, "code"])
       # and the description
-      assess_name <- dt[["assessments"]][, "desc"]
+      assess_name <- dat[["assessments"]][, "desc"]
       # the names of questions
       looknames <- assess[, "name"]
+      # the strings to use to decode values
+      rtable <- do.call("rbind", dat$assessments$fields)
+      rtable <- rtable[!is.na(rtable$rtable), c("name", "rtable")]
       
       # get codes from multiple choice variables
-      assess_lkp <- dt$assessments$lkptables
+      assess_lkp <- dat$assessments$lkptables
       lkp <- list()
       for(i in seq_along(assess_lkp)){
         l <- .decode_lkptable(assess_lkp[[i]])
@@ -93,60 +94,58 @@ as.data.frame.CM_list <- function(x,
       assess_id <- character()
       assess_name <- character()
       looknames <- character()
+      rtable <- data.frame()
       lkp <- list()
     }
     
     # add codes from registration
-    reg_lkp <- .decode_lkptable(dt$registry$lkptables)
-    
+    reg_lkp <- .decode_lkptable(dat$registry$lkptables)
     lkp <- c(reg_lkp, lkp)
     
+    # also the table strings
+    reg_rtable <- dat$registry$fields[,c("name","rtable")]
+    reg_rtable <- reg_rtable[!is.na(reg_rtable$rtable), ]
+    rtable <- rbind(rtable, reg_rtable)
+    rtable$rtable <- gsub("_lkp","_",rtable$rtable)
+    
+    # remove tricot questions
+    rtable <- rtable[!grepl("char_", rtable$name), ]
     # remove lkp table with farmers names
-    keep <- !grepl("qst163", names(lkp))
-    
-    lkp <- lkp[keep]
-    
-    # paste the ids of each assessments
-    looknames <- c(regs_name,
-                   paste(rep(assess_id, each = length(looknames)), 
-                         looknames, sep = "_"))
+    rtable <- rtable[!grepl("qst163", rtable$name), ]
     
+    # add assessment code
+    assesscode <- lapply(strsplit(rtable$rtable, "_"), function(x) x[1])
+    rtable$assess <- do.call("rbind", assesscode)
+    rtable$name <- paste(rtable$assess, rtable$name, sep = "_")
     
     # trial data
-    trial <- dt[["data"]]
+    trial <- dat[["data"]]
     
-    # get the values from the trial data
-    trial <- lapply(looknames, function(x){
-      i <- names(trial) %in% x
-      y <- trial[i]
-      y
-    })
+    # replace codes by labels in multi choice questions 
+    n_rtable <- nrow(rtable)
     
-    trial <- do.call("cbind", trial)
-    
-    # now replace codes from lkp tables in the trial data
-    names(lkp) <- gsub("_opts$","",names(lkp))
-    
-    keep <- names(lkp) %in% names(trial)
-    
-    lkp <- lkp[keep]
-    
-    # remove assessment questions
-    keep <- !names(lkp) %in% assess_q$name
-    
-    lkp <- lkp[keep]
-    
-    nm_lkp <- names(lkp)
-    
-    for(i in seq_along(lkp)){
-      l <- lkp[[i]]
-      trial[[nm_lkp[i]]] <- factor(trial[[nm_lkp[i]]], levels = l$id, labels = l$label)
+    for (i in seq_len(n_rtable)) {
+      
+      string_i <- rtable[i, "rtable"]
+      var_i <- rtable[i, "name"]
+      l <- match(string_i, names(lkp))
+      l <- lkp[[l]]
+      
+      trial[var_i] <- gsub(" ", "; ", trial[[var_i]])
+      
+      for (j in seq_along(l$id)) {
+        
+        trial[var_i] <- gsub(l$id[j], l$label[j], trial[[var_i]])
+        
+      }
+      
+      
       
     }
     
     # split geolocation info
     # check if geographic location is available
-    geoTRUE <- grepl("farmgoelocation|geopoint|gps", names(trial))
+    geoTRUE <- grepl("farmgoelocation|geopoint|gps|geotrial|pointofdel", names(trial))
     
     # if is available, then split the vector as lon lat
     if(any(geoTRUE)){
@@ -161,7 +160,7 @@ as.data.frame.CM_list <- function(x,
         newname <- names(geo)[[i]]
         newname <- gsub("farmgoelocation", "_farm_geo", newname)
         newname <- gsub("__", "_", newname)
-        newname <- paste0(newname, c("_longitude","_latitude"))
+        newname <- paste0(newname, c("_longitude","_latitude", "_elevation","_gps_precision"))
         
         lonlat <- geo[i]
         
@@ -176,7 +175,7 @@ as.data.frame.CM_list <- function(x,
         
         lonlat[lonlat == "NA"] <- NA
         
-        lonlat <- lonlat[, c(2,1)]
+        lonlat <- lonlat[, c(2,1,3,4)]
         
         lonlat <- as.data.frame(lonlat, stringsAsFactors = FALSE)
         
@@ -205,11 +204,17 @@ as.data.frame.CM_list <- function(x,
     
     # replace numbers in question about overall vs local 
     if (length(tricotvslocal) > 1) {
-      trial[tricotvslocal] <-
-        lapply(trial[tricotvslocal], function(x) {
-          y <- factor(x, levels = c("1", "2"), labels = c("Better", "Worse"))
-          as.character(y)
-        })
+      
+      if (all(c(1, 2) %in% unlist(trial[tricotvslocal]))) {
+      
+        trial[tricotvslocal] <-
+          lapply(trial[tricotvslocal], function(x) {
+            y <- factor(x, levels = c("1", "2"), labels = c("Better", "Worse"))
+            as.character(y)
+          })
+        
+      }
+      
     }
     
     # reshape it into a long format 
@@ -240,7 +245,7 @@ as.data.frame.CM_list <- function(x,
   }
   
   # comparisons and package
-  comps <- dt[["packages"]][, "comps"]
+  comps <- dat[["packages"]][, "comps"]
   
   if (ncomp == 3) {
     comps <- lapply(comps, function(x) {
@@ -264,7 +269,7 @@ as.data.frame.CM_list <- function(x,
   
   comps <- as.data.frame(comps, stringsAsFactors = FALSE)
   
-  pack <- cbind(dt[["packages"]][, c("package_id","farmername")], comps)
+  pack <- cbind(dat[["packages"]][, c("package_id","farmername")], comps)
   
   # add project name
   pack$project_name <- project_name
@@ -316,7 +321,7 @@ as.data.frame.CM_list <- function(x,
   assess_name <- sort(tolower(assess_name))
   output$moment <- factor(output$moment, levels = c("package",
                                                     "registration",
-                                                    assess_name))
+                                                    rev(assess_name)))
   
   
   # reorder moment and ids
